.. _modules:

Core
====
In the core module, all unique features of the hsi-wizard are deployed. This module represents the main functionality of the package, serving as the backbone of all operations and providing essential tools that users interact with directly.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   core/datacube
   core/datacube_ops

Processing
==========

.. toctree::
   :maxdepth: 1
   :titlesonly:

   processing/spectral
   processing/cluster


Exploration
===========

The exploration module offers a function for the visual examination of DataCubes.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   exploration/plotter
   exploration/surface

Utilities
=========

.. toctree::
   :maxdepth: 2
   :titlesonly:

   utils/helper
   utils/decorators
   utils/loader


